# `google-crc32c`

This package wraps the [`google/crc32c`](https://github.com/google/crc32c)
hardware-based implementation of the CRC32C hashing algorithm. Multiple wheels
are distributed as well as source. If a wheel is not published for the python
version and platform you are using, you will need to compile crc32c using a
C toolchain.

# Currently Published Wheels

Wheels are currently published for Python 3.6, 3.7, 3.8, 3.9 for multiple
architectures. For information on building your own, please view [BUILDING.md](BUILDING.md).

## Linux
Wheels are published for `manylinux1` and `manylinux2010` for `x86_64` architectures.

- google_crc32c-1.1.0-cp36-cp36m-manylinux1_x86_64.whl
- google_crc32c-1.1.0-cp36-cp36m-manylinux2010_x86_64.whl
- google_crc32c-1.1.0-cp37-cp37m-manylinux1_x86_64.whl
- google_crc32c-1.1.0-cp37-cp37m-manylinux2010_x86_64.whl
- google_crc32c-1.1.0-cp38-cp38-manylinux1_x86_64.whl
- google_crc32c-1.1.0-cp38-cp38-manylinux2010_x86_64.whl
- google_crc32c-1.1.0-cp39-cp39-manylinux1_x86_64.whl
- google_crc32c-1.1.0-cp39-cp39-manylinux2010_x86_64.whl


## Mac OS
Wheels are published for `x86_64` architectures

- google_crc32c-1.1.0-cp36-cp36m-macosx_10_14_x86_64.whl
- google_crc32c-1.1.0-cp37-cp37m-macosx_10_14_x86_64.whl
- google_crc32c-1.1.0-cp38-cp38-macosx_10_14_x86_64.whl
- google_crc32c-1.1.0-cp39-cp39-macosx_10_14_x86_64.whl

## Windows
Wheels are published for `win32` and `win_amd64` architectures.

- google_crc32c-1.1.0-cp36-cp36m-win32.whl
- google_crc32c-1.1.0-cp36-cp36m-win_amd64.whl
- google_crc32c-1.1.0-cp37-cp37m-win32.whl
- google_crc32c-1.1.0-cp37-cp37m-win_amd64.whl
- google_crc32c-1.1.0-cp38-cp38-win32.whl
- google_crc32c-1.1.0-cp38-cp38-win_amd64.whl
- google_crc32c-1.1.0-cp39-cp39-win32.whl
- google_crc32c-1.1.0-cp39-cp39-win_amd64.whl